# Automatically generated by Pynguin.
import pylexique as module0


def test_case_0():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()


def test_case_1():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()
    var2 = var0.__len__()


def test_case_2():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()
    var2 = "q'\r5jRbq1eJN=L"
    var3 = [var2, var2, var2]
    var4 = module0.LexItem(var3)
    var5 = var4.__repr__()


def test_case_3():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()
    var2 = module0.Lexique383()
    var3 = var2.__repr__()
    var4 = "q'\r5jRbq1eJN=L"
    var5 = [var4, var4, var4]
    var6 = module0.LexItem(var5)
    var7 = var6.__repr__()
    var8 = module0.Lexique383()
    var9 = var8.__repr__()
    var10 = var8.__len__()
    var11 = var8.__repr__()


def test_case_4():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()
    var2 = module0.Lexique383()
    var3 = var2.__repr__()
    var4 = "q'\r5jRbq1eJN=L"
    var5 = [var4, var4, var4]
    var6 = module0.LexItem(var5)
    var7 = var6.__repr__()
    var8 = module0.Lexique383()
    var9 = var8.__repr__()
    var10 = var8.__len__()
    var11 = var6.to_dict()


def test_case_5():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()
    var2 = module0.LexEntryTypes()
