# Automatically generated by Pynguin.
import pylexique as module0


def test_case_0():
    try:
        var0 = []
        var1 = module0.LexItem(var0)
    except BaseException:
        pass


def test_case_1():
    try:
        var0 = []
        var1 = module0.LexItem(var0)
    except BaseException:
        pass


def test_case_2():
    try:
        var0 = '25,86'
        var1 = module0.Lexique383(var0)
    except BaseException:
        pass
